package;

import haxegon.*;

class Factory 
{
	public static var s_seenFullIntro:Bool = false;
	public static var s_seenShoppingTutorial:Bool = false;
	
	private static function retryPreviousChoice()
	{
		GameScene.lastChoice.repeat();
		GameScene.situationQueue.unshift(GameScene.lastChoice);
	}
	
	public static function make(id:String)
	{
		var situations:Array<Situation> = [];
		
		switch (id)
		{
			case "INTRO":
				if (s_seenFullIntro)
				{
					var event:SituationEvent = new SituationEvent("13 and Homeless", "You have been cursed by a terrible wizard! You're homeless and alone. You'd better find some shelter quick!", "card_birthday_distress");
					event.addButton("OK", "Let's go");
					event.addEffect("ui", 1);
					situations.push(event);
				}
				else
				{
					var event:SituationEvent = new SituationEvent("Congratulations!", "It's your birthday! You go out in the street and play with your friends!", "card_birthday");
					event.addButton("OK", "Hooray!");
					situations.push(event);
					
					event = new SituationEvent("Whoops", "You knocked into a wizard while running through the market. He dropped an expensive-looking vial and it broke!", "card_birthday_distress");
					event.addButton("OK", "Oops");
					situations.push(event);

					event = new SituationEvent("Oh no", "FOOLISH CHILD! I CURSE YOU AND YOUR RIDICULOUS BIRTHDAY HAT! MAY YOU BE ALONE EVERY BIRTHDAY AND HAVE NOTHING!", "card_evil_wizard");
					event.addButton("OK", "Dang");
					situations.push(event);

					event = new SituationEvent("The curse!", "Your friends are nowhere to be seen. You go home, but your parents act like strangers. You're locked out. Maybe that curse was real?", "card_birthday");
					event.addButton("OK", "Uh oh");
					situations.push(event);

					event = new SituationEvent("13 and Homeless", "You'd better find some shelter quick!", "card_birthday_distress");
					event.addButton("OK", "Let's go");
					event.addEffect("ui", 1);
					situations.push(event);
					
					s_seenFullIntro = true;
				}
				
			case "SHOPPING_TUTORIAL":
				var event:SituationEvent = new SituationEvent("You're rich!", "You've made some money! Click the Shopping button to go and spend it!", "card_work");
				event.addButton("OK", "Okay!");
				situations.push(event);
				Factory.s_seenShoppingTutorial = true;
			
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// CORE GAME LOOP
			///////////////////////////////////////////////////////////////////////////////////////////////////
			
			case "SEASON_MAIN":
				var season:SituationNewSeason = new SituationNewSeason(GameSession.get().season);
				situations.push(season);
				
				var choice:SituationChoice = new SituationChoice("What will you do this season?");
				choice.addCard("WORK", "Work", "card_work");
				choice.addCard("STUDY", "Study", "card_study_books");
				if (GameSession.get().foundWizardTower)
				{
					choice.addCard("ADVENTURE", "Adventure!", "card_adventure");
				}
				else
				{
					choice.addCard("ADVENTURE_FOREST", "Adventure!", "card_adventure");
				}
				situations.push(choice);
				
				var choice:SituationChoice = new SituationChoice("You've got some free time!");
				switch (GameSession.get().shelter)
				{
					case 0: choice.addCard("RELAX", "Relax", "card_home_homeless");
					case 1: choice.addCard("RELAX", "Relax", "card_home_tent");
					case 2: choice.addCard("RELAX", "Relax", "card_home_shack");
					case 3: choice.addCard("RELAX", "Relax", "card_home_house");
				}
				
				if (GameSession.get().season == 2)
				{
					// Autumn festival.
					choice.addCard("FESTIVAL", "Festival", "card_festival_stalls");
				}
				else
				{
					choice.addCard("SOCIALISE", "Go Out", "card_work_inn");
				}
				
				if (GameSession.get().magic >= 2 && GameSession.get().cursed)
				{
					choice.addCard("UNCURSE", "Research", "card_study_magic");
				}
				
				situations.push(choice);
			
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// WORKING BLOCK
			///////////////////////////////////////////////////////////////////////////////////////////////////
			
			case "WORK":
				var choice:SituationChoice = new SituationChoice("Where will you work?");
				choice.addCard("WORK_STABLES", "Stables", "card_work_stable");
				choice.addCard("WORK_INN", "Inn", "card_work_inn");
				choice.addCard("WORK_LIBRARY", "Library", "card_work_library");
				situations.push(choice);

			case "WORK_STABLES":
				var description:String = "";
				var injured:Bool = GameSession.get().warfare < 3;
				
				if (injured)
				{
					switch (Random.int(1, 3))
					{
						case 1: description = "You swept out the stables! The horse kicked you.";
						case 2: description = "You set out the feed! The horse bit you.";
						case 3: description = "You tidied the paddock! The horse chased you and you fell over.";
					}
				}
				else
				{
					switch (Random.int(1, 3))
					{
						case 1: description = "You swept out the stables! It's exhausting work. The horse tried to kick you, but you dodged.";
						case 2: description = "You set out the feed! It's exhausting work. The horse tried to bite you but you parried it.";
						case 3: description = "You tidied the paddock! It's exhausting work. The horse chased you and you leapt over a fence.";
					}
				}
				
				var event:SituationEvent = new SituationEvent("You worked at the stables!", description, "card_work_stable");
				if (Random.chance(50))
				{
					event.addEffect("strength", 1);
				}
				else if (Random.chance(50))
				{
					event.addEffect("warfare", 1);
				}
				
				event.addEffect("health", (injured ? -2 : -1));
				event.addEffect("money", 8 + GameSession.get().strength);
				event.addButton("OK", "Okay!");
				situations.push(event);
				
				if (!injured && !GameSession.get().horseFriend)
				{
					var event:SituationEvent = new SituationEvent("I'm impressed!", "Good job handling that horse, ha ha! I'll sell him to you at a discount!", "card_farmer");
					event.addButton("OK", "Thanks!");
					situations.push(event);
					
					GameSession.get().horseFriend = true;
				}
				
			case "WORK_INN":
				var description:String = "";
				var busy:Bool = Random.bool();
				if (busy)
				{
					description = "The inn was packed! You're exhausted. ";
				}
				else
				{
					description = "The inn was quiet! There weren't many customers. ";
				}
				
				if (GameSession.get().charisma < 3)
				{
					description += " You hardly got any tips.";
				}
				else if (GameSession.get().charisma < 6)
				{
					description += " You're starting to get some tips.";
				}
				else
				{
					if (!busy)
					{
						description += " They loved you, though, and they tipped well!";
					}
					else
					{
						description += " Still, the customers love you now and they're tipping well!";
					}
				}
				
				var event:SituationEvent = new SituationEvent("You worked at the inn!", description, "card_work_inn");
				if (Random.chance(50)) {
					event.addEffect("charisma", 1);
				}
				if (busy)
				{
					event.addEffect("health", -1);
				}
				event.addEffect("money", Std.int((busy ? 5 : 3) + (busy ? 1.5 : 1) * GameSession.get().charisma));
				event.addButton("OK", "Okay!");
				situations.push(event);
				
			case "WORK_LIBRARY":
				if (GameSession.get().wisdom < 2)
				{
					// Go back and ask again.
					var event:SituationEvent = new SituationEvent("Rejected!", "The librarian turns you away when you can't read book titles!", "card_work_library");
					event.addButton("OK", "Aw.");
					situations.push(event);
					retryPreviousChoice();
				}
				else if (GameSession.get().wisdom < 4)
				{
					var event:SituationEvent = new SituationEvent("You worked at the library!", "You shelved books all season, and mostly put them in the right places!", "card_work_library");
					event.addEffect("money", 5);
					event.addButton("OK", "Okay!");
					situations.push(event);
				}
				else if (GameSession.get().wisdom < 6)
				{
					var event:SituationEvent = new SituationEvent("You worked at the library!", "You shelved books all season! You're good at filing!", "card_work_library");
					event.addEffect("money", 10);
					event.addButton("OK", "Okay!");
					situations.push(event);
				}
				else
				{
					var event:SituationEvent = new SituationEvent("You worked at the library!", "The librarian asks you to write copies! You learn a few things from the books you're working on...", "card_work_library");
					if (Random.bool())
					{
						event.addEffect("wisdom", 1);
					}
					else
					{
						event.addEffect("magic", 1);
					}
					event.addEffect("money", 16 + 1*(GameSession.get().wisdom-6));
					event.addButton("OK", "Okay!");
					situations.push(event);
				}
	
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// STUDYING BLOCK
			///////////////////////////////////////////////////////////////////////////////////////////////////
				
			case "STUDY":
				if (GameSession.get().money < 5)
				{
					// Go back and ask again.
					var event:SituationEvent = new SituationEvent("You can't afford tuition!", "School costs $5! You don't have the money.", "card_study_books");
					event.addButton("OK", "Aw.");
					situations.push(event);
					
					retryPreviousChoice();
				}
				else
				{
					var choice:SituationChoice = new SituationChoice("What do you want to study?");
					choice.addCard("STUDY_BOOKS", "Books", "card_study_books");
					choice.addCard("STUDY_MANNERS", "Etiquette", "card_study_manners");
					choice.addCard("STUDY_MAGIC", "Magic!", "card_study_magic");
					situations.push(choice);
				}

			case "STUDY_BOOKS":
				var description:String = "";
				if (GameSession.get().wisdom == 0) {
					description = "You learned the shapes of most of the letters!";
				} else if (GameSession.get().wisdom == 1) {
					description = "You learned how letters come together to make words! You can read!";
				} else if (GameSession.get().wisdom <= 4) {
					description = "Your reading's improving!";
					if (GameSession.get().wisdom == 3) {
						description = description + " You learned how to write your own name!";
					}
				} else if (GameSession.get().wisdom == 5) {
					description = "You can write and copy complete sentences!";
				} else {
					description = "Your reading and writing are improving, and you're learning more about the world!";
				}
				
				var event:SituationEvent = new SituationEvent("You hit the books!", description, "card_study_books");
				event.addEffect("wisdom", 1);
				event.addEffect("money", -5);
				event.addButton("OK", "Okay!");
				situations.push(event);
				
				if (GameSession.get().wisdom >= 6 && !GameSession.get().foundWizardTower)
				{
					var event:SituationEvent = new SituationEvent("You read about a wizard...", "He seems familiar! The book says he lives in a tower, and you could reach it by horse...", "card_adventure_tower");
					event.addButton("OK", "Nice");
					situations.push(event);
					GameSession.get().foundWizardTower = true;
				}

			case "STUDY_MANNERS":
				var description:String = "";
				if (GameSession.get().charisma <= 1) {
					description = "You learned to start conversations by making small talk!";
				} else if (GameSession.get().charisma <= 3) {
					description = "You learned to use the cutlery on the outside first!";
				} else if (GameSession.get().charisma <= 5) {
					description = "You learned to keep conversations going by expressing interest in the other person!";
				} else if (GameSession.get().charisma <= 7) {
					description = "You learned when it's appropriate to share your own interests and insights!";
				} else if (GameSession.get().charisma <= 9) {
					description = "You learned to respect other perspectives and have good conversations on difficult topics!";
				} else {
					description = "Every day, you become more of a joy to be around!";
				}
				var event:SituationEvent = new SituationEvent("You went to etiquette class!", description, "card_study_manners");
				event.addEffect("charisma", 1);
				event.addEffect("money", -5);
				event.addButton("OK", "Okay!");
				situations.push(event);

			case "STUDY_MAGIC":
				if (GameSession.get().wisdom < 2)
				{
					// Go back and ask again.
					var event:SituationEvent = new SituationEvent("You aren't ready!", "You can't read yet? Go to the other class!", "card_study_magic");
					event.addButton("OK", "Aw.");
					situations.push(event);
					
					retryPreviousChoice();
				}
				else if (GameSession.get().weaponmagic <= 0)
				{
					// Go back and ask again.
					var event:SituationEvent = new SituationEvent("You don't have the tools!", "Come back when you have a wand or staff!", "card_study_magic");
					event.addButton("OK", "Aw.");
					situations.push(event);
					
					retryPreviousChoice();
				}
				else
				{
					var description:String = "";
					if (GameSession.get().magic <= 1) {
						description = "You learned some neat ways to shuffle cards!";
					} else if (GameSession.get().magic <= 2) {
						description = "You learned some sleight of hand tricks!";
					} else if (GameSession.get().magic <= 3) {
						description = "You learned some general misdirection skills!";
					} else if (GameSession.get().magic <= 4) {
						description = "You can now make your enemies choose any number you want!";
					} else if (GameSession.get().magic <= 5) {
						description = "You learned how to make things appear when no-one expects it!";
					} else {
						description = "You're becoming more and more powerful!";
					}
					
					var event:SituationEvent = new SituationEvent("You studied magic!", description, "card_study_magic");
					event.addEffect("magic", 1);
					event.addEffect("money", -5);
					event.addButton("OK", "Okay!");
					situations.push(event);
				}
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// ADVENTURING BLOCK
			///////////////////////////////////////////////////////////////////////////////////////////////////
				
			case "ADVENTURE":
				var choice:SituationChoice = new SituationChoice("Where will you go?");
				choice.addCard("ADVENTURE_FOREST", "The Forest", "card_adventure");
				choice.addCard("ADVENTURE_TOWER", "Tower", "card_adventure_tower");
				situations.push(choice);

			case "ADVENTURE_TOWER":
				if (GameSession.get().vehicle <= 0)
				{
					// No horse!
					var event:SituationEvent = new SituationEvent("Too Far", "You need a horse to make this journey.", "card_adventure_tower");
					event.addButton("OK", "Aw.");
					situations.push(event);
					retryPreviousChoice();
				}
				else
				{
					var combatStrength:Int = GameSession.get().warfare;
					var usingMagic:Bool = (GameSession.get().weaponmagic > 0);

					var event1:SituationEvent = new SituationEvent("The wizard!", "The wizard comes out of his tower onto the bridge! He doesn't seem happy to see you!", "card_adventure_tower");
					event1.addEffect("ui_hide_shop", 1);
					event1.addButton("OK", "Hey!");
					situations.push(event1);
					
					if (GameSession.get().beatTheWizard)
					{
						// "Why did you come back?!"
						var event:SituationEvent = new SituationEvent("Why are you here?", "I said never to come back! Haven't you caused me enough trouble?", "card_evil_wizard");
						event.addButton("OK", "Nope!");
						situations.push(event);

						event = new SituationEvent("Fight!", "You already know the wizard's tricks! You crush him in an instant!", "card_adventure_tower");
						event.addButton("OK", "Die!");
						situations.push(event);

						event = new SituationEvent("What A Nice Tower", "The evil wizard is dead! That means you get all of his stuff!", "card_adventure_tower");
						event.addEffect("ui", -1);
						event.addEffect("tower", 1);
						event.addButton("OK", "Yeah!");
						situations.push(event);
						
						TitleScene.achieve("Evil Overlord");
						
						if (usingMagic)
						{
							GameSession.get().towerOwner_Mage = true;
							event = new SituationEvent("It's My Tower Now", "You move into the tower and rule over the mountains. You're the evil wizard now!", "card_adventure_tower");
							event.addButton("RESTART", "Nice");
							situations.push(event);
						}
						else
						{
							GameSession.get().towerOwner_Warlord = true;
							event = new SituationEvent("It's My Tower Now", "You move into the tower and rule over the mountains as a benevolent warlord.", "card_adventure_tower");
							event.addButton("RESTART", "Nice");
							situations.push(event);
						}
					}
					else
					{
						if (GameSession.get().weaponmelee == 0 && GameSession.get().weaponmagic == 0)
						{
							// whoops!
							var event1:SituationEvent = new SituationEvent("Are you ready?", "You really should have brought a weapon! You have regrets...", "card_adventure_tower");
							event1.addButton("OK", "Oops");
							situations.push(event1);
						}
						else if (GameSession.get().weaponmelee > 0)
						{
							combatStrength = 2 + Std.int((0.5 + 0.5*GameSession.get().weaponmelee) * (GameSession.get().warfare));
							var weapon:String = (GameSession.get().weaponmelee == 2) ? "Metal Sword" : "Wood Sword";
							var event1:SituationEvent = new SituationEvent("Are you ready?", "Your combat strength with your " + weapon + " and Warfare is " + combatStrength + ". Let's go!", "card_adventure_tower");
							event1.addButton("OK", "Fight!");
							situations.push(event1);
						}
						else if (GameSession.get().weaponmagic > 0)
						{
							usingMagic = true;
							combatStrength = Std.int((0.5 + 0.5*GameSession.get().weaponmagic) * (GameSession.get().magic + 0.5*GameSession.get().wisdom));
							
							var weapon:String = (GameSession.get().weaponmelee == 2) ? "Oak Staff" : "Wand";
							var event1:SituationEvent = new SituationEvent("Are you ready?", "Your combat strength with your " + weapon + ", Magic and Wisdom is " + combatStrength + ". Let's go!", "card_adventure_tower");
							event1.addButton("OK", "Fight!");
							situations.push(event1);
						}
						
						var difficulty:Int = 15;
						
						if (combatStrength <= 10)
						{
							var event1:SituationEvent = new SituationEvent("Fight!", "You rush at the wizard! But it's all a blur - and when you wake up you're back in town, with a massive headache...", "card_evil_wizard");
							event1.addEffect("health", -2);
							event1.addButton("OK", "Ow");
							situations.push(event1);
						}
						else 
						{
							// Close match
							var event1:SituationEvent = new SituationEvent("Fight!", "Your battle is long and intense! Lightning arcs between the towers and strikes the ground around you!", "card_adventure_tower");
							event1.addButton("OK", "Wow");
							situations.push(event1);
						
							if (combatStrength < difficulty)
							{
								event1 = new SituationEvent("Forced to Retreat", "In the end, you cannot keep pressure up on the wizard. You are forced to fall back. If only you'd been better...", "card_adventure_tower");
								event1.addButton("OK", "Aw.");
								situations.push(event1);
							}
							else
							{
								// Win!
								var event:SituationEvent = new SituationEvent("Victory!", "You fight your way up close and disarm the wizard! He's at your mercy!", "card_adventure_tower");
								event.addButton("OK", "Ha!");
								situations.push(event);
								
								event = new SituationEvent("Fine, Have It Your Way", "Fine! I'll dispel your stupid curse!", "card_evil_wizard");
								event.addButton("OK", "Thanks");
								situations.push(event);
								
								event = new SituationEvent("THE CURSE IS LIFTED", "You feel something heavy within you lighten!", "card_birthday_cured");
								event.addEffect("curseLift", 1);
								event.addButton("OK", "Wow!");
								situations.push(event);

								event = new SituationEvent("Well done", "Now we're even! Never come back!", "card_evil_wizard");
								event.addButton("OK", "Bye");
								situations.push(event);
								
								GameSession.get().beatTheWizard = true;
							}
						}
					}
				}
				
			case "ADVENTURE_FOREST":
				var combatStrength:Int = GameSession.get().warfare;
				var usingMagic:Bool = false;
				
				if (GameSession.get().weaponmelee == 0 && GameSession.get().weaponmagic == 0)
				{
					// whoops!
					var event1:SituationEvent = new SituationEvent("You went on an adventure!", "The forests are scary! You should have brought a weapon!", "card_adventure");
					event1.addEffect("ui_hide_shop", 1);
					event1.addButton("OK", "Okay!");
					situations.push(event1);
				}
				else if (GameSession.get().weaponmelee > 0)
				{
					combatStrength = Std.int((0.5 + 0.5*GameSession.get().weaponmelee) * (2 + GameSession.get().warfare));
					var weapon:String = (GameSession.get().weaponmelee == 2) ? "Metal Sword" : "Wood Sword";
					var event1:SituationEvent = new SituationEvent("You went on an adventure!", "Your combat strength with your " + weapon + " and Warfare is " + combatStrength + ". Let's go!", "card_adventure");
					event1.addEffect("ui_hide_shop", 1);
					event1.addButton("OK", "Okay!");
					situations.push(event1);
				}
				else if (GameSession.get().weaponmagic > 0)
				{
					usingMagic = true;
					combatStrength = Std.int((0.5 + 0.5*GameSession.get().weaponmagic) * (GameSession.get().magic + 0.5*GameSession.get().wisdom));
					
					var weapon:String = (GameSession.get().weaponmelee == 2) ? "Oak Staff" : "Wand";
					var event1:SituationEvent = new SituationEvent("Are you ready?", "Your combat strength with your " + weapon + ", Magic and Wisdom is " + combatStrength + ". Let's go!", "card_adventure");
					event1.addEffect("ui_hide_shop", 1);
					event1.addButton("OK", "Okay!");
					situations.push(event1);
				}
				
				if (combatStrength <= Random.int(4, 6))
				{
					// SLIMES
					var event1:SituationEvent = new SituationEvent("Slimes!", "You meet some dangerous slimes!", "card_adventure");
					event1.addButton("OK", "Whoa");
					situations.push(event1);
					
					// Possible combat outcomes: fail, difficult battle, easy win
					var difficulty:Int = Random.int(1, 2);
					
					if (combatStrength < difficulty) {
						var event2:SituationEvent = new SituationEvent("Slimes!", "They're really tough! You have to run away!", "card_adventure");
						event2.addEffect("ui_hide_shop", -1);
						event2.addEffect("health", -2);
						//event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addButton("OK", "Flee!");
						situations.push(event2);
					} else if (combatStrength <= difficulty + 1) {
						var event2:SituationEvent = new SituationEvent("Slimes!", "It's a difficult fight but you take them down! You find some treasure they hid in a log!", "card_adventure");
						event2.addEffect("money", Random.int(3, 5));
						event2.addEffect("ui_hide_shop", -1);
						event2.addEffect("health", -1);
						if (Random.chance(65)) event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addButton("OK", "Hooray!");
						situations.push(event2);
					} else {
						var event2:SituationEvent = new SituationEvent("Slimes!", "You crush the slimes easily! You find some treasure they hid in a log!", "card_adventure");
						event2.addEffect("money", Random.int(3, 7));
						event2.addEffect("ui_hide_shop", -1);
						if (Random.chance(65)) event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addButton("OK", "Hooray!");
						situations.push(event2);
					}
				}
				else if (combatStrength <= Random.int(12, 18) || GameSession.get().killedTheBear)
				{
					// WOLVES
					var event1:SituationEvent = new SituationEvent("Wolves!", "You meet some dangerous wolves!", "card_adventure");
					event1.addButton("OK", "Whoa");
					situations.push(event1);
					
					// Possible combat outcomes: fail, difficult battle, easy win
					var difficulty:Int = Random.int(4, 8);
					
					if (combatStrength < difficulty) {
						var event2:SituationEvent = new SituationEvent("Wolves!", "They're really tough! You have to run away!", "card_adventure");
						event2.addEffect("ui_hide_shop", -1);
						event2.addEffect("health", -2);
						//event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addButton("OK", "Flee!");
						situations.push(event2);
					} else if (combatStrength <= difficulty + 4) {
						var event2:SituationEvent = new SituationEvent("Wolves!", "It's a difficult fight but you take them down! You find some treasure they hid under a rock!", "card_adventure");
						event2.addEffect("money", Random.int(7, 12));
						event2.addEffect("ui_hide_shop", -1);
						event2.addEffect("health", -1);
						if (Random.chance(65)) event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addButton("OK", "Hooray!");
						situations.push(event2);
					} else {
						var event2:SituationEvent = new SituationEvent("Wolves!", "You crush the wolves easily! You find some treasure they hid under a rock!", "card_adventure");
						event2.addEffect("money", Random.int(10, 18));
						event2.addEffect("ui_hide_shop", -1);
						if (Random.chance(65)) event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addButton("OK", "Hooray!");
						situations.push(event2);
					}					
				}
				else
				{
					// BEAR
					var event1:SituationEvent = new SituationEvent("BEAR", "HOLY MOTHER, IT'S A BEAR", "card_adventure");
					event1.addButton("OK", "Help");
					situations.push(event1);
					
					// Possible combat outcomes: fail, difficult battle, easy win
					var difficulty:Int = Random.int(13, 16);
					
					if (combatStrength < difficulty) {
						var event2:SituationEvent = new SituationEvent("BEAR", "HOW IS IT SO STRONG AND YET SO FAST", "card_adventure");
						event2.addEffect("health", -2);
						event2.addButton("OK", "PLAY DEAD");
						situations.push(event2);

						if (Random.chance(0.5))
						{
							var event3:SituationEvent = new SituationEvent("BEAR", "It mauls you a bit more!", "card_adventure");
							event3.addEffect("health", -1);
							event3.addButton("OK", "Ow");
							situations.push(event3);
						}
						
						var event4:SituationEvent = new SituationEvent("BEAR", "The bear finally gets bored and wanders off.", "card_adventure");
						event4.addEffect("ui_hide_shop", -1);
						event4.addButton("OK", "Phew");
						situations.push(event4);
					} else if (combatStrength <= difficulty + 6) {
						var event2:SituationEvent = new SituationEvent("BEAR", "It's a difficult fight, but you finally win! You head to the bear's cave and steal all its savings.", "card_adventure");
						event2.addEffect("money", Random.int(20, 30));
						event2.addEffect("health", -2);
						event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addEffect("ui_hide_shop", -1);
						event2.addButton("OK", "Hooray!");
						situations.push(event2);
						
						GameSession.get().killedTheBear = true;
						TitleScene.achieve("Bearly Survived");
					} else {
						var event2:SituationEvent = new SituationEvent("Bear!", "You dispatch the bear with only minor wounds! You go to the bear's cave and steal all its savings.", "card_adventure");
						event2.addEffect("money", Random.int(20, 30));
						event2.addEffect("health", -1);
						event2.addEffect(usingMagic ? "magic" : "warfare", 1);
						event2.addEffect("ui_hide_shop", -1);
						event2.addButton("OK", "Hooray!");
						situations.push(event2);
						
						GameSession.get().killedTheBear = true;
						TitleScene.achieve("Bearly Survived");
					}						
				}
				
				++GameSession.get().totalAdventures;
				if (GameSession.get().totalAdventures >= 8 && !GameSession.get().foundWizardTower)
				{
					var event:SituationEvent = new SituationEvent("You glimpse a distant tower...", "You see a dark tower in the distance, about a horse ride away. Maybe somewhere to explore?", "card_adventure_tower");
					event.addButton("OK", "Cool");
					situations.push(event);
					GameSession.get().foundWizardTower = true;
				}
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// STAYING HOME BLOCK
			///////////////////////////////////////////////////////////////////////////////////////////////////
				
			case "RELAX":
				switch (GameSession.get().shelter)
				{
					case 0: // Homeless
						switch (GameSession.get().season)
						{
							case 0, 2: // Spring and autumn
								var event:SituationEvent = new SituationEvent("You rested in an alley.", "It's a rainy season! You got wet, so you couldn't relax. You need to buy some shelter...", "card_home_homeless");
								event.addButton("OK", "Okay");
								situations.push(event);
								
							case 1: // Summer
								var event:SituationEvent = new SituationEvent("You rested in an alley.", "It's not very comfy. You should go shopping for somewhere to stay.", "card_home_homeless");
								event.addEffect("health", 1);
								event.addButton("OK", "Okay");
								situations.push(event);
							
							case 3: // Winter
								var event:SituationEvent = new SituationEvent("You rested in an alley.", "It's really cold! You can't stop shivering!", "card_home_homeless");
								event.addEffect("health", -2);
								event.addButton("OK", "Okay");
								situations.push(event);
						}

					case 1: // Tent
						switch (GameSession.get().season)
						{
							case 0, 2:
								var event:SituationEvent = new SituationEvent("You slept in your tent.", "It's not much, but it's yours!", "card_home_tent");
								event.addEffect("health", 1);
								event.addButton("OK", "Okay");
								situations.push(event);
								
							case 1:
								var event:SituationEvent = new SituationEvent("You slept in your tent.", "You're camping out in summer! It's rather pleasant.", "card_home_tent");
								event.addEffect("health", 2);
								event.addButton("OK", "Okay");
								situations.push(event);
								
							case 3:
								var event:SituationEvent = new SituationEvent("You slept in your tent.", "The winter nights are too cold without a fire. You can't relax...", "card_home_tent");
								event.addButton("OK", "Okay");
								situations.push(event);
						}						
					case 2: 
						// also change SituationChoice::repeat
						// TODO: spec 'relax in shack'
						var event:SituationEvent = new SituationEvent("You slept in your shack.", "It's nice and warm and windproof", "card_home_shack");
						event.addEffect("health", 2);
						event.addButton("OK", "Okay");
						situations.push(event);
					case 3: 
						// also change SituationChoice::repeat
						// TODO: spec 'relax in house'
						var event:SituationEvent = new SituationEvent("You slept in your house!", "It's so comfy!", "card_home_house");
						event.addEffect("health", 3);
						event.addButton("OK", "Okay");
						situations.push(event);
				}
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// SOCIALISING BLOCK
			///////////////////////////////////////////////////////////////////////////////////////////////////
				
			case "SOCIALISE":
				if (GameSession.get().money >= 2)
				{
					var event:SituationEvent = new SituationEvent("You spent a night on the town!", "You don't know anyone, but the atmosphere's nice!", "card_work_inn");
					event.addEffect("health", 1);
					//event.addEffect("charisma", 1);
					event.addEffect("money", -2);
					event.addButton("OK", "Okay!");
					situations.push(event);
					
					if (GameSession.get().charisma >= 5 && !GameSession.get().foundWizardTower)
					{
						var event:SituationEvent = new SituationEvent("You meet a traveller!", "She tells you about a wizard's tower, a horse ride away, that may be the home of your nemesis...", "card_adventure_tower");
						event.addButton("OK", "Thanks!");
						situations.push(event);
						GameSession.get().foundWizardTower = true;
					}
				}
				else
				{
					var event:SituationEvent = new SituationEvent("You couldn't afford anything.", "You tried all the social spots, but they kicked you out when you didn't buy anything.", "card_work_inn");
					event.addButton("OK", "Aw.");
					situations.push(event);
				}
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// FESTIVAL BLOCK
			///////////////////////////////////////////////////////////////////////////////////////////////////

			case "FESTIVAL":
				// 'festival' event!
				var event:SituationEvent = new SituationEvent("The Harvest Festival", "It's the biggest party every year! There are stalls everywhere, and the Queen runs a fighting tournament!", "card_festival_stalls");
				event.addButton("OK", "Let's go!");
				situations.push(event);
				
				var choice:SituationChoice = new SituationChoice("Where will you go?");
				choice.addCard("FESTIVAL_STALLS", "Stalls", "card_festival_stalls");
				if (GameSession.get().cursed) {
					choice.addCard("FESTIVAL_MYSTIC", "Fortune", "card_festival_mystic");
				}
				choice.addCard("FESTIVAL_TOURNAMENT", "Tournament", "card_festival_tournament");
				situations.push(choice);
				
			case "FESTIVAL_STALLS":
				if (GameSession.get().money >= 4)
				{
					var event:SituationEvent = new SituationEvent("You eat so much!", "You fill up on burgers, eclairs and crystallised ginger... what a day!", "card_festival_stalls");
					event.addEffect("health", 2);
					event.addEffect("money", -4);
					event.addButton("OK", "Okay!");
					situations.push(event);
				}
				else
				{
					var event:SituationEvent = new SituationEvent("You couldn't afford anything.", "You can't buy anything at the stalls, but it all smells wonderful!", "card_festival_stalls");
					event.addEffect("health", 1);
					event.addButton("OK", "OK");
					situations.push(event);
				}
				
			case "FESTIVAL_MYSTIC":
				switch (GameSession.get().mysticProgress)
				{
					case 0:
						// oh wow, what a terrible curse! I'll go research it.
						var event:SituationEvent = new SituationEvent("The fortune teller is intrigued.", "There is a heavy curse upon your soul...", "card_festival_mystic");
						event.addButton("OK", "Yup");
						situations.push(event);

						event = new SituationEvent("It looks bad", "It grows stronger... Maybe it can be cured, but only before your 18th birthday. Then it will become permanent.", "card_festival_mystic");
						event.addButton("OK", "Oh no");
						situations.push(event);
						
						if (GameSession.get().year < 17)
						{
							event = new SituationEvent("A promise", "I will look into this curse. Come back next year.", "card_festival_mystic");
							event.addButton("OK", "Okay!");
							situations.push(event);
						}
						else
						{
							event = new SituationEvent("That's in a few months!", "Oh. Good luck?", "card_festival_mystic");
							event.addButton("OK", "Thanks");
							situations.push(event);
						}
						
						GameSession.get().mysticProgress = 1;
					case 1:
						// I've heard of this. Give me $20 and I'll go find an answer.
						var event:SituationEvent = new SituationEvent("The fortune teller is intrigued.", "There is a heavy curse upon your soul...", "card_festival_mystic");
						event.addButton("OK", "Yup");
						situations.push(event);

						event = new SituationEvent("An offer", "I know of a cure. Pay me $20 and I'll bring it here for you next year.", "card_festival_mystic");
						event.addButton("OK", "Hmm...");
						situations.push(event);
						
						if (GameSession.get().year < 17)
						{
							// BUY / DON'T BUY
							var choice:SituationChoice = new SituationChoice("Pay the fortune teller?");
							choice.addCard("FESTIVAL_MYSTIC_PAY1_YES", "Give $20", "card_work");
							choice.addCard("FESTIVAL_MYSTIC_PAY1_NO", "No way", "card_festival_mystic");
							situations.push(choice);
						}
						else
						{
							event = new SituationEvent("That's too late!", "Oh. Really? Good luck, then.", "card_festival_mystic");
							event.addButton("OK", "Thanks");
							situations.push(event);
						}
						
					case 2:
						// I've got a cure but someone else reserved it. Give me $35 for it?
						var event:SituationEvent = new SituationEvent("The fortune teller is intrigued.", "There is a heavy curse upon your soul...", "card_festival_mystic");
						event.addButton("OK", "Yup");
						situations.push(event);

						event = new SituationEvent("An offer", "I happen to have a cure, but I brought it here for someone else. It will cost you dearly...", "card_festival_mystic");
						event.addButton("OK", "Hmm...");
						situations.push(event);
						
						// BUY / DON'T BUY
						var choice:SituationChoice = new SituationChoice("Pay the fortune teller?");
						choice.addCard("FESTIVAL_MYSTIC_PAY2_YES", "Give $35", "card_work");
						choice.addCard("FESTIVAL_MYSTIC_PAY2_NO", "No way", "card_festival_mystic");
						situations.push(choice);
				}
				
			case "FESTIVAL_MYSTIC_PAY1_YES":
				if (GameSession.get().money >= 20)
				{
					var event:SituationEvent = new SituationEvent("You pay the fortune teller!", "I will bring your cure. Come see me next year.", "card_festival_mystic");
					event.addEffect("money", -20);
					event.addButton("OK", "Deal!");
					situations.push(event);

					GameSession.get().mysticProgress = 2;
				}
				else
				{
					var event:SituationEvent = new SituationEvent("You can't afford it.", "You don't have $20 on you.", "card_festival_mystic");
					event.addButton("OK", "Aw.");
					situations.push(event);
					
					retryPreviousChoice();
				}

			case "FESTIVAL_MYSTIC_PAY1_NO":
				var event:SituationEvent = new SituationEvent("No Deal.", "Come back when you have money, hmm?", "card_festival_mystic");
				event.addButton("OK", "Jerk");
				situations.push(event);
				
			case "FESTIVAL_MYSTIC_PAY2_YES":
				if (GameSession.get().money >= 35)
				{
					var event:SituationEvent = new SituationEvent("You pay the fortune teller!", "Here. Drink this.", "card_festival_mystic");
					event.addEffect("money", -35);
					event.addButton("OK", "Okay...");
					situations.push(event);

					TitleScene.achieve("Fortunate Cure");
					
					var event:SituationEvent = new SituationEvent("THE CURSE IS LIFTED", "You feel something heavy within you lighten!", "card_birthday_cured");
					event.addEffect("curseLift", 1);
					event.addButton("OK", "Wow!");
					situations.push(event);

					var event:SituationEvent = new SituationEvent("Well done", "Your future looks much brighter. Don't waste it.", "card_birthday_cured");
					event.addButton("OK", "Thanks!");
					situations.push(event);
					
					GameSession.get().mysticProgress = 3;
				}
				else
				{
					var event:SituationEvent = new SituationEvent("You can't afford it.", "You don't have $35 on you.", "card_festival_mystic");
					event.addButton("OK", "Aw.");
					situations.push(event);
					
					retryPreviousChoice();
				}

			case "FESTIVAL_MYSTIC_PAY2_NO":
				var event:SituationEvent = new SituationEvent("No Deal.", "Come back when you have money, hmm? But I'm afraid my buyer will pick this up soon...", "card_festival_mystic");
				event.addButton("OK", "Jerk");
				situations.push(event);
				
			case "FESTIVAL_TOURNAMENT":
				if (GameSession.get().year < 17)
				{
					var event:SituationEvent = new SituationEvent("The tournament!", "You have to be 17 to enter the tournament, but anyone can watch! You sit down to watch the fights!", "card_festival_tournament");
					event.addButton("OK", "Wow!");
					situations.push(event);
					
					event = new SituationEvent("The tournament!", "The country's best soldiers clash with swords. It's incredibly exciting! You find yourself taking notes...", "card_festival_tournament");
					event.addEffect("warfare", 1);
					event.addButton("OK", "Neat");
					situations.push(event);
					
					if (GameSession.get().year >= 15)
					{
						if (!GameSession.get().seenPrincexx)
						{
							if (GameSession.get().year == 15)
							{
								event = new SituationEvent("The finals", "The Prince and/or Princess turned 17 this year and joined the tournament! They're so dashing!", "card_princexx");
								event.addButton("OK", "Wow!");
								situations.push(event);
							}
							else
							{
								event = new SituationEvent("The finals", "You see a new challenger: the Prince and/or Princess! They're just two years older than you, and already so gorgeous and strong!", "card_princexx");
								event.addButton("OK", "Wow!");
								situations.push(event);
							}
							
							GameSession.get().seenPrincexx = true;
						}

						event = new SituationEvent("The finals", "The Prince and/or Princess wins the tournament and stands as the champion! Wow! You want to smell their hair.", "card_princexx");
						event.addButton("OK", "Phew!");
						situations.push(event);
					}
				}
				else
				{
					var event:SituationEvent = new SituationEvent("The tournament!", "You're finally old enough to enter! You step into the ring!", "card_festival_tournament");
					event.addButton("OK", "Let's go!");
					situations.push(event);
					
					var combatStrength:Int = GameSession.get().warfare;
					
					if (GameSession.get().weaponmelee > 0)
					{
						combatStrength = Std.int((0.5 + 0.5 * GameSession.get().weaponmelee) * (2 + GameSession.get().warfare));
						var weapon:String = (GameSession.get().weaponmelee == 2) ? "Metal Sword" : "Wood Sword";
						event = new SituationEvent("First round", "Your combat strength is " + combatStrength + "! You lift your " + weapon + "!", "card_festival_tournament");
						event.addEffect("ui_hide_shop", 1);
						event.addButton("OK", "Fight!");
						situations.push(event);
					}
					else
					{
						event = new SituationEvent("First round", "You didn't bring a sword! The crowd murmurs with excitement! Your combat strength is only " + combatStrength + "!!", "card_festival_tournament");
						event.addEffect("ui_hide_shop", 1);
						event.addButton("OK", "Fight!");
						situations.push(event);
					}
					
					// battle strength: we should expect 20 by this point. let's be kind and say:
					// 2 is enough for the first round
					// 4 is a partway knockout
					// 6 is enough to reach the finals
					// 10 is enough to beat the prince(ss)
					// 16 is enough to kill the queen
					if (combatStrength < 2)
					{
						event = new SituationEvent("Defeated", "You are unceremoniously knocked out within fifteen seconds.", "card_festival_tournament");
						event.addEffect("health", -1);
						event.addButton("OK", "Ow");
						situations.push(event);
					}
					else if (combatStrength < 4)
					{
						event = new SituationEvent("Defeated in the second round!", "You win your first fight, but you face a town guard in the second round and rapidly find yourself on the ground.", "card_festival_tournament");
						event.addEffect("health", -1);
						event.addButton("OK", "Ow");
						situations.push(event);
					}
					else if (combatStrength < 6)
					{
						event = new SituationEvent("Made it to the semifinals!", "You win several rounds but lose to a veteran mercenary. She offers you a handshake before you're carried off.", "card_festival_tournament");
						event.addEffect("health", -1);
						event.addButton("OK", "Ow");
						situations.push(event);
					}
					else
					{
						// Facing the prince(ss)
						event = new SituationEvent("It's the finals!", "You won every fight! Now you're standing across from the Prince and/or Princess, a new challenger, ready to fight for the championship!", "card_princexx");
						event.addButton("OK", "Fight!");
						situations.push(event);

						if (combatStrength < 8)
						{
							event = new SituationEvent("Wow", "They're even better up close! You're dazzled by their quick movements. In seconds, their sword is at your throat. The crowd applauds!", "card_princexx");
							event.addEffect("warfare", 1);
							event.addButton("OK", "Wow!");
							situations.push(event);

							event = new SituationEvent("What a match!", "The Prince and/or Princess is the champion, once again! Incredible. You're a little jealous...", "card_princexx");
							event.addEffect("health", 1);
							event.addButton("OK", "Hmm");
							situations.push(event);
						}
						else if (combatStrength < 10)
						{
							event = new SituationEvent("Wow", "They step in fast! They're the toughest fighter you've faced yet, but you think you can take them...", "card_princexx");
							event.addButton("OK", "Wow!");
							situations.push(event);

							event = new SituationEvent("A tense battle", "You match their dance with your own and press them back, but in the end the Prince and/or Princess knocks you down!", "card_princexx");
							event.addEffect("warfare", 1);
							event.addButton("OK", "Aw");
							situations.push(event);
							
							event = new SituationEvent("What a match!", "The crowd applauds. The Prince and/or Princess is the champion, once again! Incredible. If only you'd been a little better...", "card_princexx");
							event.addEffect("health", 1);
							event.addButton("OK", "Hmm");
							situations.push(event);
						}
						else
						{
							// WE GONNA WIN
							event = new SituationEvent("Wow", "They step in fast! They're the toughest fighter you've faced yet, but you think you can take them...", "card_princexx");
							event.addButton("OK", "Wow!");
							situations.push(event);

							event = new SituationEvent("A tense battle", "You match their dance with your own, press them back, and knock their sword to the floor! Undeterred, they move in to wrestle!", "card_princexx");
							event.addEffect("warfare", 1);
							event.addButton("OK", "Aw");
							situations.push(event);
							
							if (GameSession.get().strength < 3)
							{
								event = new SituationEvent("Wrestling", "They're incredibly strong! You find yourself flying through the air...", "card_princexx");
								event.addButton("OK", "Aw");
								situations.push(event);
								
								event = new SituationEvent("What a match!", "The crowd applauds. The Prince and/or Princess is the champion, once again! Incredible. If only you'd been a little stronger...", "card_princexx");
								event.addButton("OK", "Hmm");
								situations.push(event);
							}
							else
							{
								event = new SituationEvent("Wrestling", "You easily handle the Prince and/or Princess and toss them to the ground!", "card_princexx_disarmed");
								event.addButton("OK", "Yes!");
								situations.push(event);
								
								event = new SituationEvent("Wrestling", "They look up at you, smiling. You've got them down! \"I guess I've met my match! Congratulations!\"", "card_princexx_disarmed");
								event.addButton("OK", "You did!");
								situations.push(event);
								
								TitleScene.achieve("Champion");
								
								var choice:SituationChoice = new SituationChoice("What will you do?");
								choice.addCard("FESTIVAL_TOURNAMENT_CELEBRATE", "Help up", "card_princexx_disarmed");
								choice.addCard("FESTIVAL_TOURNAMENT_KILL", "Finish!", "card_princexx_disarmed");
								situations.push(choice);
							}
						}
					}
				}
			
			case "FESTIVAL_TOURNAMENT_CELEBRATE":
				var event:SituationEvent = new SituationEvent("Champion!", "You're the hero of the whole festival! You get a huge prize purse, and everyone buys you food and drink all evening!", "card_festival_stalls");
				event.addEffect("money", 30);
				event.addEffect("health", 2);
				event.addButton("OK", "Wow!");
				situations.push(event);
				
			case "FESTIVAL_TOURNAMENT_KILL":
				var event:SituationEvent = new SituationEvent("Wait", "What", "card_princexx_disarmed");
				event.addButton("OK", "Die!");
				situations.push(event);

				event = new SituationEvent("Surrounded By Guards", "The crowd gasps! You've killed the Prince and/or Princess! The Queen demands your head!!", "card_festival_tournament");
				event.addButton("OK", "FIGHT");
				situations.push(event);
				
				var combatStrength:Int = GameSession.get().warfare;
				
				if (GameSession.get().weaponmelee > 0)
				{
					combatStrength = Std.int((0.5 + 0.5 * GameSession.get().weaponmelee) * (2 + GameSession.get().warfare));
				}
				
				if (combatStrength >= 14)
				{
					// KILL THE QUEEN
					event = new SituationEvent("Fight! Fight! Fight!", "You easily cut down the guards around you and charge towards the Queen's throne!", "card_queen");
					event.addButton("OK", "KILL");
					situations.push(event);
					
					event = new SituationEvent("Regicide!", "You sever the Queen's organs from her other organs! Everyone gasps! They're not sure what to do next!", "card_queen");
					event.addButton("OK", "Yes!");
					situations.push(event);
					
					var choice:SituationChoice = new SituationChoice("What will you do?");
					choice.addCard("CROWN_TAKE", "Take Crown", "card_crown");
					choice.addCard("CROWN_KILL", "Kill Crown", "card_crown");
					situations.push(choice);
				}
				else
				{
					// Cut down by guards
					event = new SituationEvent("Fight! Fight! Fight!", "You fight your hardest, but you're overwhelmed by the sheer numbers of guards and captured! If only you'd been better...", "card_festival_tournament");
					event.addButton("OK", "Aw.");
					situations.push(event);
					
					event = new SituationEvent("You Died", "You are executed for regicide.", "card_birthday_dead");
					event.addEffect("ui", -1);
					event.addButton("RESTART", "Aw...");
					situations.push(event);
				}

			case "CROWN_TAKE":
				var event:SituationEvent = new SituationEvent("A New Reign", "You take up the crown! You're the ruler now!", "card_crown");
				event.addEffect("money", 9900);
				event.addButton("OK", "Phew");
				situations.push(event);
				
				GameSession.get().royal = true;
				GameSession.get().monarch = true;
				TitleScene.achieve("Monarch");
				
				if (GameSession.get().cursed)
				{
					var event:SituationEvent = new SituationEvent("Summon the court wizard.", "He promises to fix this terrible curse instantly, your Majesty!", "card_evil_wizard");
					event.addButton("OK", "Ta");
					situations.push(event);

					var event:SituationEvent = new SituationEvent("THE CURSE IS LIFTED", "You feel something heavy within you lighten!", "card_birthday_cured");
					event.addEffect("curseLift", 1);
					event.addButton("OK", "Wow!");
					situations.push(event);

					var event:SituationEvent = new SituationEvent("Well done", "You're curse-free! Isn't life wonderful?", "card_birthday_cured");
					event.addButton("OK", "Yeah!");
					situations.push(event);
				}
				
			case "CROWN_KILL":
				var event:SituationEvent = new SituationEvent("A New Republic", "You shatter the crown into pieces (and pocket a few). Monarchy is dead. The country is reborn as a people's democracy!", "card_festival_stalls");
				event.addEffect("money", 200);
				event.addButton("OK", "Phew");
				situations.push(event);
				
				TitleScene.achieve("Republican");
				GameSession.get().endedTheMonarchy = true;
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// FIXING THE CURSE YOURSELF
			///////////////////////////////////////////////////////////////////////////////////////////////////
			
			case "UNCURSE":
				// Steps:
				if (GameSession.get().wisdom < 6)
				{
					var description:String = "You research your curse in the library.";
					if (GameSession.get().wisdom >= 4)
					{
						description = "You think you're close to getting it!";
					}
					var event:SituationEvent = new SituationEvent("Hitting the Books", description, "card_work_library");
					if (Random.chance(50)) 
					{
						event.addEffect("wisdom", 1);
					}
					event.addButton("OK", "Hmm");
					situations.push(event);
				}
				else
				{
					var event:SituationEvent = new SituationEvent("Research Complete", "You're pretty sure you have a way to reverse the curse!", "card_work_library");
					event.addButton("OK", "Yes!");
					situations.push(event);
					
					// Got enough wisdom. Do a magic item check.
					if (GameSession.get().weaponmagic <= 0)
					{
						// Go back and ask again.
						var event:SituationEvent = new SituationEvent("You don't have the tools!", "You'll need a wand or staff to try and fix it, and $8 of stuff for each attempt!", "card_study_magic");
						event.addButton("OK", "Aw.");
						situations.push(event);
						
						retryPreviousChoice();
					}
					else
					{
						if (GameSession.get().money < 8)
						{
							var event:SituationEvent = new SituationEvent("You don't have the money!", "Sadly, you need $8 to buy the rare magical agents in the remedy...", "card_study_magic");
							event.addButton("OK", "Aw.");
							situations.push(event);
							
							retryPreviousChoice();
						}
						else
						{
							var event:SituationEvent = new SituationEvent("Attempting a Cure!", "You buy the magical agents you need and prepare the magic circle!", "card_study_magic");
							event.addEffect("money", -8);
							event.addButton("OK", "Yesss");
							situations.push(event);

							// - you need to spend money on materials
							// - 'magic' skill check. Might fail.
							if (GameSession.get().magic <= 2)
							{
								var event:SituationEvent = new SituationEvent("There's An Explosion", "The ritual went horribly wrong! You need to learn much more about magic.", "card_study_magic");
								event.addEffect("health", -2);
								event.addEffect("magic", 1);
								event.addButton("OK", "Ow");
								situations.push(event);
							}
							else if (GameSession.get().magic <= 4)
							{
								var event:SituationEvent = new SituationEvent("That Didn't Work", "You're not ready for this yet, but at least it didn't explode in your face!", "card_study_magic");
								event.addEffect("magic", 1);
								event.addButton("OK", "Hmm");
								situations.push(event);
							}
							else if (GameSession.get().magic <= 6)
							{
								var event:SituationEvent = new SituationEvent("Almost right!", "You extract a potion, but it's the wrong colour and burns like acid. You're really close...", "card_study_magic");
								event.addEffect("health", -1);
								event.addEffect("magic", 1);
								event.addButton("OK", "Hmm");
								situations.push(event);
							}
							else
							{
								//SUCCESS
								var event:SituationEvent = new SituationEvent("THE CURSE IS LIFTED", "You feel something heavy within you lighten!", "card_birthday_cured");
								event.addEffect("curseLift", 1);
								event.addButton("OK", "Wow!");
								situations.push(event);

								TitleScene.achieve("Did The Research");
								
								var event:SituationEvent = new SituationEvent("It worked!", "You're curse-free! Isn't life wonderful?", "card_birthday_cured");
								event.addButton("OK", "Yeah!");
								situations.push(event);
							}
						}
					}
				}
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// EVENTS AT END OF YEARS
			///////////////////////////////////////////////////////////////////////////////////////////////////
			
			case "ENDOFYEAR":
				if (GameSession.get().cursed)
				{
					var birthday:SituationEvent = new SituationEvent("The curse!", "Everything you own crumbles to dust before your eyes!", "card_birthday");
					birthday.addButton("CURSED", "Aw.");
					situations.push(birthday);
					
					var birthday2:SituationEvent = new SituationEvent("Congratulations!", "You are now " + GameSession.get().year + " years old! Everyone has forgotten you.", "card_birthday");
					birthday2.addButton("CURSED", "Aw...");
					situations.push(birthday2);

					if (GameSession.get().year == 16)
					{
						if (GameSession.get().mysticProgress >= 1)
						{
							var birthday:SituationEvent = new SituationEvent("Remember...", "If the curse isn't lifted by your 18th birthday, it will last forever...", "card_festival_mystic");
							birthday.addButton("CURSED", "Uh oh");
							situations.push(birthday);
						}
						else
						{
							var birthday:SituationEvent = new SituationEvent("You're growing up", "Only two years until you come of age... you wonder if you'll be able to lift the curse by then?", "card_birthday");
							birthday.addButton("CURSED", "Uh oh");
							situations.push(birthday);
						}
					} 
					else if (GameSession.get().year == 16)
					{
						if (GameSession.get().mysticProgress >= 1)
						{
							var birthday:SituationEvent = new SituationEvent("Remember...", "You only have one more year to lift the curse!", "card_festival_mystic");
							birthday.addButton("CURSED", "Uh oh");
							situations.push(birthday);
						}
						else
						{
							var birthday:SituationEvent = new SituationEvent("You're growing up", "One more year to your 18th birthday. Will you ever be able to lift the curse, or should you just give up?", "card_birthday");
							birthday.addButton("CURSED", "Sigh");
							situations.push(birthday);
						}
					}
				}
				else
				{
					var birthday:SituationEvent = new SituationEvent("Congratulations!", "You are now " + GameSession.get().year + " years old - and you're free of the curse!", "card_birthday");
					birthday.addButton("FREE", "Hooray!");
					situations.push(birthday);
					
					var birthday:SituationEvent = new SituationEvent("Plan Ahead...", "You've got a little time left until your 18th birthday. What can you achieve?", "card_birthday_distress");
					birthday.addButton("FREE", "Let's Go");
					situations.push(birthday);
				}
				
			///////////////////////////////////////////////////////////////////////////////////////////////////
			// DIRECT ENDINGS
			///////////////////////////////////////////////////////////////////////////////////////////////////
				
			case "ENDING":
				if (GameSession.get().cursed)
				{
					var dead:SituationEvent = new SituationEvent("18th Birthday (Cursed)", "It's your 18th birthday and you never lifted the curse. You'll live with this curse forever, drifting from place to place, starting over every spring...", "card_birthday");
					dead.addButton("RESTART", "Aw");
					dead.addEffect("ui", -1);
					situations.push(dead);
				}
				else
				{
					var dead:SituationEvent = new SituationEvent("18th Birthday (Curse Free!)", "Hooray! You have escaped the Terrible Curse.", "card_birthday");
					dead.addButton("OK", "Yay!");
					dead.addEffect("ui", -1);
					situations.push(dead);
					
					if (GameSession.get().monarch)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You rule the kingdom happily for many years.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else if (GameSession.get().endedTheMonarchy)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "The country flourishes as a new constitutional democracy.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else if (GameSession.get().warfare > 10)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You live a long and successful life as a mercenary.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else if (GameSession.get().magic > 10)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You live a long and successful life as a national magician.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else if (GameSession.get().charisma > 10)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You live a long and successful life as a popular socialite.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else if (GameSession.get().wisdom > 10)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You take up a post as the city librarian and live a long and happy life amongst your books.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else if (GameSession.get().strength > 10)
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You buy up the stables and take over. That horse never comes to like you, but you gain its grudging respect.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}
					else
					{
						var outcome:SituationEvent = new SituationEvent("Epilogue", "You live a long and happy life.", "card_birthday");
						outcome.addButton("RESTART", "Yay!");
						situations.push(outcome);
					}					
				}
				
			case "DEAD":
				var dead:SituationEvent = new SituationEvent("You Died", "You have expired.", "card_birthday_dead");
				dead.addEffect("ui", -1);
				dead.addButton("RESTART", "Aw.");
				situations.push(dead);
				
		}
		
		while (situations.length > 0)
		{
			GameScene.situationQueue.unshift(situations.pop());
		}
	}
}
