package;

import openfl.Lib;
import haxegon.*;

class GameScene 
{
	static inline var maxShopButtonAnimFrame:Int = 12;
	
	var scenetime:Float = 0;
	var delayframes:Int;
	
	public static var lastChoice:SituationChoice;
	public static var situationQueue:Array<Situation>;

	var hoverShopButton:Bool;
	var shopButtonOffsetFrame:Int;
	
	var isShopping:Bool;
	var shop:Shop;
	var dismissedSituation:Bool;
	
	function init() 
	{
		reset();
		
		beginSeason();
		
		// Intro cutscene. (Pushed to start of queue before 'beginSeason'.)
		Factory.make("INTRO");
	}

	function reset()
	{
		hoverShopButton = false;
		shopButtonOffsetFrame = 0;
		isShopping = false;
		shop = new Shop();
		
		dismissedSituation = false;
		
		situationQueue = [];
		
		scenetime = 0;
		delayframes = 20;
	}
	
	function beginSeason()
	{
		GameSession.get().ui_hide_shop = 0;
		
		Factory.make("SEASON_MAIN");
	}
	
	function update() 
	{
		scenetime += 1 / 60;

		if (isShopping || GameSession.get().ui_hide_shop > 0)
		{
			if (shopButtonOffsetFrame < maxShopButtonAnimFrame)
			{
				++shopButtonOffsetFrame;
			}
			
			if (isShopping)
			{
				if (!situationQueue[0].isComplete())
				{
					situationQueue[0].update();
				}
				
				shop.update();
				if (shop.isComplete())
				{
					isShopping = false;
				}
				return;
			}
		}
		
		if (GameSession.get().ui_hide_shop == 0)
		{
			if (shopButtonOffsetFrame > 0)
			{
				--shopButtonOffsetFrame;
			}
			else 
			{
				hoverShopButton = (Mouse.x > 540 && Mouse.y < 35);
				if (hoverShopButton && Mouse.leftclick())
				{
					isShopping = true;
					shop.startShopping();
					shop.startShopping();
					
					if (!Std.is(situationQueue[0], SituationNewSeason))
					{
						situationQueue[0].dismiss();
						if (Std.is(situationQueue[0], SituationChoice))
						{
							dismissedSituation = true;
						}
					}
					
					return;
				}
			}
		}
		
		if (delayframes > 0)
		{
			--delayframes;
			return;
		}
		
		if (situationQueue[0].isComplete())
		{
			if (dismissedSituation)
			{
				situationQueue[0].repeat();
				dismissedSituation = false;
				return;
			}
			
			var completedSituation:Situation = situationQueue.shift();
			
			delayframes = 10;
			
			// Implement result of completed situation. Choices add events to the queue.
			if (Std.is(completedSituation, SituationEvent) && cast(completedSituation, SituationEvent).getChoiceResult() == "RESTART")
			{
				GameSession.get().reset();
				Scene.change(TitleScene);
				return;
			}
			else if (GameSession.get().health <= 0)
			{
				Factory.make("DEAD");
				return;
			}
			else if (GameSession.get().money >= 5 && !Factory.s_seenShoppingTutorial)
			{
				Factory.make("SHOPPING_TUTORIAL");
				Factory.s_seenShoppingTutorial = true;
				return;
			}
			else if (Std.is(completedSituation, SituationChoice))
			{
				lastChoice = cast(completedSituation, SituationChoice);
				Factory.make(lastChoice.getChoiceResult());
			}

			if (situationQueue.length == 0)
			{
				++GameSession.get().season;

				if (GameSession.get().season >= 4)
				{
					++GameSession.get().year;
					
					if (GameSession.get().year >= 18)
					{
						Factory.make("ENDING");
						return;
					}
					
					GameSession.get().season = 0;
					
					// Do some shenanigans here
					Factory.make("ENDOFYEAR");
					var tempQueue:Array<Situation> = situationQueue;
					situationQueue = [];

					if (GameSession.get().cursed)
					{
						GameSession.get().resetyear();
					}
					beginSeason();
					
					while (tempQueue.length > 0)
					{
						situationQueue.unshift(tempQueue.pop());
					}
				}
				else
				{
					beginSeason();
				}
			}
		}

		situationQueue[0].update();
	}
	
	public static function renderPlaza(scenetime:Float, showplaza:Bool)
	{
		Gfx.drawimage(0, 0, "background_plaza_1");

		{
			var cloudshift:Float = ((640 - 192) + 2.4 * scenetime) % 800;
			var cloudx:Float = 640 - cloudshift;
			Gfx.drawimage(cloudx, 26, "background_cloud");
		}

		{
			var cloudshift:Float = ((640 - 580) + 2.4 * scenetime) % 800;
			var cloudx:Float = 640 - cloudshift;
			Gfx.drawimage(cloudx, -26, "background_cloud");
		}
		
		if (showplaza)
		{
			Gfx.drawimage(0, 15, "background_plaza_2");
		}
	}
	
	function renderBackground()
	{
		// Background
		renderPlaza(scenetime, true);

		// Characters
		if (GameSession.get().ui > 0)
		{
			var herobob:Float = 0.5 + 0.5 * Math.sin(2 * Math.PI * (Lib.getTimer() / 1200));
			var heroy:Int = Std.int(85 + 2 * herobob);
			
			if (GameSession.get().vehicle == 1)
			{
				heroy -= 39;
			}
			
			Gfx.drawimage(0, heroy, "character_hero");
			
			if (GameSession.get().weaponmelee == 1) Gfx.drawimage(0, heroy, "character_hero_sword1");
			if (GameSession.get().weaponmelee == 2) Gfx.drawimage(0, heroy, "character_hero_sword2");
			if (GameSession.get().weaponmagic == 1) Gfx.drawimage(0, heroy, "character_hero_wand");
			if (GameSession.get().weaponmagic == 2) Gfx.drawimage(0, heroy, "character_hero_staff");
			if (GameSession.get().gift == 1) Gfx.drawimage(0, heroy, "character_hero_rose");
			if (GameSession.get().vehicle == 1) Gfx.drawimage(0, heroy, "character_hero_horse");
			if (GameSession.get().monarch) Gfx.drawimage(0, heroy, "character_hero_crown");
		}
	}

	function renderSituation()
	{
		situationQueue[0].render();
		
		if (isShopping)
		{
			shop.render();
		}
	}
	
	function renderUI()
	{
		// Draw UI
		Gfx.drawimage(0, 0, "ui_season");
		
		CustomText.render(50, 6, "Age " + GameSession.get().year);

		
		Gfx.rotation(5*Std.int(6*scenetime), Gfx.CENTER, Gfx.CENTER);
		switch (GameSession.get().season)
		{
			case 0: Gfx.drawimage(13, 12, "ui_season_spring");
			case 1: Gfx.drawimage(13, 12, "ui_season_summer");
			case 2: Gfx.drawimage(13, 12, "ui_season_autumn");
			case 3: Gfx.drawimage(13, 12, "ui_season_winter");
		}
		Gfx.reset();
		
		switch (GameSession.get().season)
		{
			case 0: CustomText.render(50, 21, "Spring", 1);
			case 1: CustomText.render(50, 21, "Summer", 1);
			case 2: CustomText.render(50, 21, "Autumn", 1);
			case 3: CustomText.render(50, 21, "Winter", 1);
		}

		var shopButtonX:Int = 547 + Std.int(100 * Math.pow(shopButtonOffsetFrame / maxShopButtonAnimFrame, 3));
		if (hoverShopButton)
		{
			Gfx.drawimage(shopButtonX, 5, "ui_shop_button_lit");
		}
		else 
		{
			Gfx.drawimage(shopButtonX, 5, "ui_shop_button");
		}
		CustomText.render(shopButtonX + 11, 7, "Shopping!", hoverShopButton ? 4 : 1);
		
		Gfx.drawimage(0, 0, "ui_stats_perm");
		CustomText.render(5, 312, "Health", 0);
		for (hp in 0 ... 5)
		{
			if (hp < GameSession.get().health)
			{
				Gfx.drawimage(60 + 15 * hp, 318, "ui_heart");
			}
			else
			{
				Gfx.drawimage(60 + 15 * hp, 318, "ui_heart_empty");
			}
		}
		
		if (GameSession.get().cursed)
		{
			CustomText.render(220, 312, "(Cursed!)", 1);
		}
		
		CustomText.render(5, 335, "Str", 0);
		CustomText.render(34, 335, "" + GameSession.get().strength, 3);
		
		CustomText.render(59, 335, "Wis", 0);
		CustomText.render(89, 335, "" + GameSession.get().wisdom, 3);
		
		CustomText.render(115, 335, "Cha", 0);
		CustomText.render(146, 335, "" + GameSession.get().charisma, 3);
		
		CustomText.render(172, 335, "Mag", 0);
		CustomText.render(204, 335, "" + GameSession.get().magic, 3);
		
		CustomText.render(227, 335, "War", 0);
		CustomText.render(263, 335, "" + GameSession.get().warfare, 3);
		
		Gfx.drawimage(0, 0, "ui_stats_temp");
		CustomText.render(303, 312, "Money", 0);
		CustomText.render(349, 312, "$" + GameSession.get().money, 3);
		/*
		CustomText.render(405, 312, "Reputation", 0);
		CustomText.render(487, 312, "+" + GameSession.get().reputation, 3);
		CustomText.render(516, 312, "School Grade", 0);
		switch (GameSession.get().grade)
		{
			case 0: CustomText.render(609, 312, "F", 3);
			case 1: CustomText.render(609, 312, "C", 3);
			case 2: CustomText.render(609, 312, "C+", 3);
			case 3: CustomText.render(609, 312, "B", 3);
			case 4: CustomText.render(609, 312, "B+", 3);
			case 5: CustomText.render(609, 312, "A", 3);
			case 6: CustomText.render(609, 312, "A+", 3);
			case 7: CustomText.render(609, 312, "S", 3);
			case 8: CustomText.render(609, 312, "S", 3);
			case 9: CustomText.render(609, 312, "S", 3);
			case 10: CustomText.render(609, 312, "S", 3);
		}*/
		
		CustomText.render(303, 335, "Shelter:", 0);
		switch (GameSession.get().shelter)
		{
			case 0: CustomText.render(363, 335, "None", 2);
			case 1: CustomText.render(363, 335, "Tent", 1);
			case 2: CustomText.render(363, 335, "Shack", 1);
			case 3: CustomText.render(363, 335, "House", 1);
		}
		CustomText.render(415, 335, "Gear:", 0);
		
		var geartext:String = "";
		switch (GameSession.get().weaponmelee)
		{
			case 1: geartext = "Wood Sword";
			case 2: geartext = "Metal Sword";
		}
		switch (GameSession.get().weaponmagic)
		{
			case 1: geartext = "Wand";
			case 2: geartext = "Oak Staff";
		}
		
		if (GameSession.get().vehicle > 0)
		{
			if (geartext == "") geartext = "Horse";
			else geartext = geartext + ", Horse";
		}

		if (GameSession.get().gift > 0)
		{
			if (geartext == "") geartext = "Rose";
			else geartext = geartext + ", Rose";
		}
		
		if (GameSession.get().monarch)
		{
			if (geartext == "") geartext = "Country";
			else geartext = geartext + ", Country";
		}

		if (GameSession.get().tower > 0)
		{
			if (geartext == "") geartext = "Tower";
			else geartext = geartext + ", Tower";
		}
		
		if (geartext == "") geartext = "Nothing";
		
		CustomText.render(460, 335, geartext, 1);		
	}
	
	function render()
	{
		renderBackground();
		renderSituation();
		
		if (GameSession.get().ui > 0)
		{
			renderUI();
		}
	}
}