package;

import haxegon.*;

class ShopItem
{
	public var stat:String;
	public var statValue:Int;
	public var name:String;
	public var desc:String;
	public var cost:Int;
	
	public function new(_stat:String, _statValue:Int, _name:String, _desc:String, _cost:Int)
	{
		stat = _stat;
		statValue = _statValue;
		name = _name;
		desc = _desc;
		cost = _cost;
	}
	
	public function isPurchaseable() : Bool
	{
		if (stat == "weaponmelee" && GameSession.get().weaponmagic > 0) return false;
		if (stat == "weaponmagic" && GameSession.get().weaponmelee > 0) return false;
		
		return statValue > Reflect.field(GameSession.get(), stat) && cost <= GameSession.get().money;
	}
	
	public function purchase()
	{
		GameSession.get().money -= cost;
		
		// Cancel opposite-type weapons.
		if (stat == "weaponmelee") GameSession.get().weaponmagic = 0;
		if (stat == "weaponmagic") GameSession.get().weaponmelee = 0;
		
		// Achievement
		if (stat == "vehicle") TitleScene.achieve("Horse");
		if (stat == "shelter" && statValue == 3) TitleScene.achieve("Homeowner");
		
		Reflect.setField(GameSession.get(), stat, statValue);
	}
}

class Shop 
{
	static inline var animMaxFrame:Int = 22;

	var items:Array<ShopItem>;
	
	var appearing:Bool;
	var animationFrame:Int;
	
	var highlightRow:Int;
	
	public function new() 
	{
		items = [];
		items.push(new ShopItem("shelter", 1, "Tent", "Basic shelter.", 4));
		items.push(new ShopItem("shelter", 2, "Shack", "Your own place in the slums!", 10));
		items.push(new ShopItem("shelter", 3, "House", "In a great school district.", 22));
		items.push(new ShopItem("weaponmelee", 1, "Wood Sword", "Use either end to hit them.", 3));
		items.push(new ShopItem("weaponmelee", 2, "Metal Sword", "With collector's certificate.", 16));
		items.push(new ShopItem("weaponmagic", 1, "Wand", "A twig. Seller says it's 'magic'.", 2));
		items.push(new ShopItem("weaponmagic", 2, "Oak Staff", "Don't cast fire, it'll burn!", 12));
		items.push(new ShopItem("vehicle", 1, "Horse", "Awful creature. Smells.", 25));
		items.push(new ShopItem("gift", 1, "Rose", "The flirtiest flower.", 1));
		
		appearing = false;
		animationFrame = 0;
	}
	
	public function startShopping()
	{
		if (GameSession.get().horseFriend)
		{
			items[7].cost = 20;
		}
		else
		{
			items[7].cost = 25;
		}
		
		appearing = true;
		animationFrame = -20;
		highlightRow = -1;
	}
	
	public function update()
	{
		if (appearing && animationFrame < animMaxFrame)
		{
			++animationFrame;
		}
		else if (!appearing && animationFrame > 0)
		{
			--animationFrame;
		}
		
		if (appearing && animationFrame >= animMaxFrame)
		{
			highlightRow = -1;
			if (Mouse.x > 130 && Mouse.x < 506)
			{
				for (i in 0 ... items.length)
				{
					var lineY:Int = 48 + 32 + 20 * i;
					if (Mouse.y >= lineY && Mouse.y < lineY + 20)
					{
						highlightRow = i;
					}
				}
			}
			// Ready to interact.
			if (Mouse.leftclick())
			{
				if (highlightRow != -1)
				{
					if (items[highlightRow].isPurchaseable())
					{
						items[highlightRow].purchase();
						
						// If we can no longer afford anything, close the shop.
						var anyPurchasable:Bool = false;
						for (i in 0 ... items.length)
						{
							if (items[i].isPurchaseable())
							{
								anyPurchasable = true;
								break;
							}
						}
						
						if (!anyPurchasable)
						{
							appearing = false;
						}
					}
				}
				else if (Mouse.x > 485 && Mouse.x < 513 && Mouse.y > 54 && Mouse.y < 82)
				{
					appearing = false;
				}
			}
		}
	}

	public function isComplete() : Bool
	{
		return (!appearing && animationFrame <= 0);
	}
	
	public function render()
	{
		if (animationFrame < 0)
		{
			return;
		}
		
		var panelY:Int = 48 - Std.int(270 * Math.pow(1 - animationFrame / animMaxFrame, 3));
		
		Gfx.drawimage(128, panelY, "shop_bg");
		
		var title:String = "Shop";
		CustomText.render(Std.int(Gfx.screenwidthmid - 0.5*CustomText.width(title)), panelY + 4, title, 1);
		
		for (i in 0 ... items.length)
		{
			var lineY:Int = panelY + 30 + 20 * i;
			var colMain:Int = 1;
			var colDesc:Int = 0;
			
			if (highlightRow == i)
			{
				Gfx.drawimage(136, lineY + 2, "shop_row_lit");
				colMain = 4;
				colDesc = 4;
			}
			
			if (!items[i].isPurchaseable())
			{
				colMain = 5;
				colDesc = 5;
			}

			CustomText.render(136, lineY, items[i].name, colMain);
			CustomText.render(235, lineY, items[i].desc, colDesc);

			var coststr:String = "$" + items[i].cost;
			CustomText.render(Std.int(503 - CustomText.width(coststr)), lineY, coststr, colMain);
		}
	}
}